package no.ntnu.idatt1002.demo.controller;

import java.io.IOException;
import javafx.event.ActionEvent;
import javafx.fxml.FXML;
import javafx.fxml.FXMLLoader;
import javafx.geometry.Rectangle2D;
import javafx.scene.Node;
import javafx.scene.Parent;
import javafx.scene.Scene;
import javafx.scene.control.Alert;
import javafx.scene.control.Alert.AlertType;
import javafx.scene.control.Dialog;
import javafx.stage.Modality;
import javafx.stage.Screen;
import javafx.stage.Stage;
import no.ntnu.idatt1002.demo.data.Budget.FileHandlingSelectedBudget;
import no.ntnu.idatt1002.demo.data.Economics.Income;

public class SceneController {

  @FXML
  public void initialize() {
  }


  /**
   * Brings up popup window to name budget
   * @throws IOException
   */
  @FXML
  public void switchIncome(ActionEvent event) throws IOException {
    //Bring up popup X
    //Let user fill in. When OK is pressed, show confirmation dialog as the name cannot be changed X
    //Create maybe a folder, and Create three new files, using the budgetName + the dateMonth as the ID //
    //Overwrite a "currentFile" file with the fileName
    //Then switch scene to the expense vs income

    //Instantiate FXML loader and loads the popup for adding expense

    FXMLLoader loader = new FXMLLoader();
    loader.setLocation(getClass().getResource("/view/CreateBudget.fxml"));

    String budgetName;

    String dialogTitle = "Create budget";

    Dialog<String> dialog = new Dialog<>();
    dialog.initModality(Modality.APPLICATION_MODAL);


    try {
      // Set the Dialog's content to the loaded FXML file
      dialog.getDialogPane().setContent(loader.load());
    } catch (IOException e) {
      showErrorDialogBox("Loading", "Error in loading dialog box", "Could not load"
          + "the AddExpense window");
    }

    // Get the controller for the loaded FXML file
    CreateBudgetController createBudgetController = new CreateBudgetController();
    // Show the Dialog and wait for the user to close it
    dialog.setTitle(dialogTitle);

    dialog.showAndWait();

    try {
      if (FileHandlingSelectedBudget.readSelectedBudget() != null) {
        switchNext(event);
      }
    } catch (IOException ioe) {
      showErrorDialogBox("", "", "");
    }
  }

  private void switchNext(ActionEvent event) throws IOException {
      FXMLLoader loader = new FXMLLoader();
      loader.setLocation(SceneController.class.getResource("/view/dualList.fxml"));
      Parent root = loader.load();
      Stage stage = (Stage)((Node)event.getSource()).getScene().getWindow();
      Scene scene = new Scene(root);
      stage.setScene(scene);
      stage.show();
  }
  private void showErrorDialogBox(String title, String header, String content) {
    Alert alert = new Alert(AlertType.ERROR);
    alert.setTitle(title);
    alert.setHeaderText(header);
    alert.setContentText(content);

    alert.showAndWait();
  }

  public void switchMainMenu(ActionEvent event) throws IOException {
    FXMLLoader loader = new FXMLLoader();
    loader.setLocation(SceneController.class.getResource("/view/SelectBudget.fxml"));

    String dialogTitle = "Select budget";
    // Load the FXML file for your dialog box
    Dialog<Income> dialog = new Dialog<>();

    try {
      // Set the Dialog's content to the loaded FXML file
      dialog.getDialogPane().setContent(loader.load());
    } catch (IOException e) {
      showErrorDialogBox("Loading error", "Error in loading dialog box", "Could not load"
          + "the AddIncome window");
    }

    //Sets the title of the dialog box
    dialog.setTitle(dialogTitle);
    // Show the Dialog and wait for the user to close it
    dialog.showAndWait();

    try {
      if (FileHandlingSelectedBudget.readSelectedBudget() != null) {
        switchChosenBudget(event);
      }
    } catch(IOException ioe) {
      showErrorDialogBox("Loading error", "Could not switch to main menu", "");
    }
  }

  private void switchChosenBudget(ActionEvent event) throws IOException {
    FXMLLoader loader = new FXMLLoader();
    loader.setLocation(SceneController.class.getResource("/view/MainMenuNew.fxml"));
    Parent root = loader.load();
    Stage stage = (Stage)((Node)event.getSource()).getScene().getWindow();
    Scene scene = new Scene(root);
    stage.setScene(scene);

    //Centralize the new screen
    Rectangle2D primScreenBounds = Screen.getPrimary().getVisualBounds();
    stage.setX((primScreenBounds.getWidth() - stage.getWidth()) / 2);
    stage.setY((primScreenBounds.getHeight() - stage.getHeight()) / 2);

    stage.show();
  }

  public void closeButton(ActionEvent actionEvent) {
    final Node source = (Node) actionEvent.getSource();
    final Stage stage = (Stage) source.getScene().getWindow();
    stage.close();
  }
}
